class HoverTank extends SHover;

var()		array<vector>		ThrusterOffsets;

simulated function PostNetBeginPlay()
{
	local vector RotX, RotY, RotZ;
	local KarmaParams kp;
	local KRepulsor rep;
	local int i;

    Super.PostNetBeginPlay(); //This must be called first so the repulsors created in SHover are overridden

    GetAxes(Rotation,RotX,RotY,RotZ);

	// Spawn and assign 'repulsors' to hold tank off the ground

	kp = KarmaParams(KParams);

	//Get rid of hover bike model
	kp.Repulsors[0].destroy();
	kp.Repulsors[1].destroy();

	kp.Repulsors.Length = ThrusterOffsets.Length;
	for(i=0;i<ThrusterOffsets.Length;i++)
	{
    	rep = spawn(class'KRepulsor', self,, Location + ThrusterOffsets[i].X * RotX + ThrusterOffsets[i].Y * RotY + ThrusterOffsets[i].Z * RotZ);
    	rep.SetBase(self);
    	rep.bHidden = true;
    	kp.Repulsors[i] = rep;
    }

	SVehicleUpdateParams();
}


simulated event SVehicleUpdateParams()
{
	local KarmaParams kp;
	local int i;

	Super.SVehicleUpdateParams();

	kp = KarmaParams(KParams);

	for(i=0;i<kp.Repulsors.Length;i++)
	{
		kp.Repulsors[i].Softness = HoverSoftness;
		kp.Repulsors[i].PenScale = HoverPenScale;
		kp.Repulsors[i].CheckDist = HoverCheckDist;
	}
}



defaultproperties
{
	Mesh=SkeletalMesh'SimpleVehicles_K.Tank'

	FPCamPos=(X=0,Y=0,Z=200)
	TPCamLookat=(X=0,Y=0,Z=120)
    TPCamDistance=900.000000

	bDrawDriverInTP=true
	bDrawMeshInFP=true

	MaxViewYaw=16000
	MaxViewPitch=16000

    DrivePos=(X=-30.000000,Y=0.0,Z=-10)

    ExitPositions(0)=(Y=-500.000000,Z=100.000000)
    ExitPositions(1)=(Y=500.000000,Z=100.000000)
    //EntryPositions(0)=(Y=-400.000000,Z=10.000000)
    //EntryPositions(1)=(Y=400.000000,Z=10.000000)
    EntryPosition=(Y=400.000000,Z=10.000000)
    EntryRadius=200

	// Left Treads
	ThrusterOffsets(0)=(X=450,Y=260,Z=-150)
	ThrusterOffsets(1)=(X=100,Y=260,Z=-150)
	ThrusterOffsets(2)=(X=-100,Y=260,Z=-150)
	ThrusterOffsets(3)=(X=-450,Y=260,Z=-150)

	// Right Treads
	ThrusterOffsets(4)=(X=450,Y=-260,Z=-150)
	ThrusterOffsets(5)=(X=100,Y=-260,Z=-150)
	ThrusterOffsets(6)=(X=-100,Y=-260,Z=-150)
	ThrusterOffsets(7)=(X=-450,Y=-260,Z=-150)

    HoverSoftness=0.020000
    HoverPenScale=1.100000
    HoverCheckDist=50.000000

	UprightStiffness=500
	UprightDamping=300

    MaxThrust=220.000000
    ForwardDampFactor=0.200000
    LateralDampFactor=0.800000

    MaxSteerTorque=180.000000
    SteerDampFactor=250.000000

	PitchTorqueFactor=50.0
    PitchDampFactor=1.000000

    BankTorqueFactor=0.000000
    BankDampFactor=0.000000

	StopThreshold=100
    VehicleMass=7.000000

	Begin Object Class=KarmaParamsRBFull Name=KParams0
		KStartEnabled=True
		KFriction=0.5
		KLinearDamping=0
		KAngularDamping=0
		bKNonSphericalInertia=True
        bHighDetailOnly=False
        bClientOnly=False
		bKDoubleTickRate=True
		bKStayUpright=True
		bKAllowRotate=True
		//SafeTimeMode=KST_Always
        KInertiaTensor(0)=10.000000
        KInertiaTensor(3)=15.000000
        KInertiaTensor(5)=15.500000
		KCOMOffset=(X=0.0,Y=0.0,Z=0.0)
        Name="KParams0"
    End Object
    KParams=KarmaParams'KParams0'
}
